package de.intevation.flys.model;

import java.io.Serializable;
import java.math.BigDecimal;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.GeneratedValue;
import javax.persistence.Column;
import javax.persistence.SequenceGenerator;
import javax.persistence.GenerationType;
import javax.persistence.JoinColumn;
import javax.persistence.OneToOne;

import org.apache.log4j.Logger;


@Entity
@Table(name = "discharge_zone")
public class DischargeZone
implements   Serializable
{
    private static Logger logger = Logger.getLogger(DischargeZone.class);


    private Integer id;

    private String gaugeName;

    private River river;

    private NamedMainValue mainValue;

    private BigDecimal lowerFactor;

    private BigDecimal upperFactor;


    public DischargeZone() {
    }


    public DischargeZone(
        String         gaugeName,
        River          river,
        NamedMainValue mainValue,
        BigDecimal     lowerFactor,
        BigDecimal     upperFactor
    ) {
        this.gaugeName   = gaugeName;
        this.river       = river;
        this.mainValue   = mainValue;
        this.lowerFactor = lowerFactor;
        this.upperFactor = upperFactor;
    }

    @Id
    @SequenceGenerator(
        name           = "SEQUENCE_DISCHARGE_ZONE_ID_SEQ",
        sequenceName   = "DISCHARGE_ZONE_ID_SEQ",
        allocationSize = 1)
    @GeneratedValue(
        strategy  = GenerationType.SEQUENCE,
        generator = "SEQUENCE_DISCHARGE_ZONE_ID_SEQ")
    @Column(name = "id")
    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    @OneToOne
    @JoinColumn(name = "river_id" )
    public River getRiver() {
        return river;
    }

    public void setRiver(River river) {
        this.river = river;
    }

    @OneToOne
    @JoinColumn(name = "named_main_value_id")
    public NamedMainValue getMainValue() {
        return mainValue;
    }

    public void setMainValue(NamedMainValue mainValue) {
        this.mainValue = mainValue;
    }

    @Column(name = "gauge_name")
    public String getGaugeName() {
        return gaugeName;
    }

    public void setGaugeName(String gaugeName) {
        this.gaugeName = gaugeName;
    }

    @Column(name = "lower_factor")
    public BigDecimal getLowerFactor() {
        return lowerFactor;
    }

    public void setLowerFactor(BigDecimal lowerFactor) {
        this.lowerFactor = lowerFactor;
    }

    @Column(name = "upper_factor")
    public BigDecimal getUpperFactor() {
        return upperFactor;
    }

    public void setUpperFactor(BigDecimal upperFactor) {
        this.upperFactor = upperFactor;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
